## Description
<!-- Please briefly describe the change and why it was required. -->


## Checklist
- [ ] Entry added to `CHANGELOG.md`.
- [ ] Tests provided; and/or
- [ ] Description of manual testing performed and explanation is included in the code and/or PR.
- [ ] Library documentation is updated.
- [ ] [Corp site](https://github.com/DataDog/documentation/) documentation is updated (link to the PR).
